@@ -75,37 +75,37 @@
     <message>
         <location filename="../directorymenuconfiguration.cpp" line="56"/>
         <source>Icon and text</source>
-        <translation type="unfinished"></translation>
+        <translation>Icon and text</translation>
     </message>
     <message>
         <location filename="../directorymenuconfiguration.cpp" line="115"/>
         <source>Choose Base Directory</source>
-        <translation type="unfinished"></translation>
+        <translation>Choose Base Directory</translation>
     </message>
     <message>
         <location filename="../directorymenuconfiguration.cpp" line="164"/>
         <source>Choose Icon</source>
-        <translation type="unfinished"></translation>
+        <translation>Choose Icon</translation>
     </message>
     <message>
         <location filename="../directorymenuconfiguration.cpp" line="164"/>
         <source>Icons (*.png *.xpm *.jpg *.svg)</source>
-        <translation type="unfinished"></translation>
+        <translation>Icons (*.png *.xpm *.jpg *.svg)</translation>
     </message>
     <message>
         <location filename="../directorymenuconfiguration.cpp" line="188"/>
         <source>Choose Label</source>
-        <translation type="unfinished"></translation>
+        <translation>Choose Label</translation>
     </message>
     <message>
         <location filename="../directorymenuconfiguration.cpp" line="189"/>
         <source>Label:</source>
-        <translation type="unfinished"></translation>
+        <translation>Label:</translation>
     </message>
     <message>
         <location filename="../directorymenuconfiguration.cpp" line="173"/>
         <source>Directory Menu</source>
-        <translation type="unfinished"></translation>
+        <translation>Directory Menu</translation>
     </message>
     <message>
         <location filename="../directorymenuconfiguration.cpp" line="173"/>
